## [0.1.0a9] - 2026-02-01

### 🚀 Features

- Improve model imports (#12)
## [0.1.0a8] - 2026-01-29

### 🚀 Features

- Support multiple local yara files (#10)
- Add base yara rules for SignatureDetector (#11)

### 📚 Documentation

- Update readme and user guide

### ⚙️ Miscellaneous Tasks

- Update badges
- Prepare v0.1.0a8
## [0.1.0a7] - 2026-01-22

### 🚀 Features

- Add security policy
- Add signature detector using yara (#9)

### ⚙️ Miscellaneous Tasks

- Remove local security policy to inherit from org
- Split default detectors into guard and scan (#8)
- Prepare v0.1.0a7
## [0.1.0a6] - 2026-01-20

### 🚀 Features

- Add all flag to installation config
- Implement core orchestration layer and client proxies (#7)

### ⚙️ Miscellaneous Tasks

- Refactor of detectors into namespaces (#6)
- Prepare v0.1.0a6
## [0.1.0a5] - 2026-01-16

### 🚀 Features

- Add language detection feature (#5)

### ⚙️ Miscellaneous Tasks

- Refactor into new structure and add better tests (#4)
- Update links
- Prepare release 0.1.0a5
## [0.1.0a4] - 2026-01-13

### 🚀 Features

- Rename property to threat_detected in DetectionResult

### ⚙️ Miscellaneous Tasks

- Improve workflow
- Prepare v0.1.0a4
## [0.1.0a3] - 2026-01-06

### 📚 Documentation

- Fix badges

### ⚙️ Miscellaneous Tasks

- Fix warning for init commit message
- Prepare v0.1.0a3
## [0.1.0a2] - 2026-01-06

### 🐛 Bug Fixes

- Export classes and bump version (#2)

### ⚙️ Miscellaneous Tasks

- Add summary step (#3)
- Prepare v0.1.0a2
## [0.1.0a1] - 2026-01-05

### 🚀 Features

- Init commit
- Add canary token feature

### ⚙️ Miscellaneous Tasks

- Finalize release workflow
- Update version
- Update workflow
- Prepare release
